==> mx-repo-manager_21.8.tar.xz: mx-repo-manager-21.8/translations/mx-repo-manager_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="66"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Välj det APT förråd du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Välj snabbaste MX förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Debian repos</source>
        <translation>Debian förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Välj snabbaste Debian förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Individual sources</source>
        <translation>Individuella källor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Restore original APT sources</source>
        <translation>Återställ original APT sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>Please wait...</source>
        <translation>Var vänlig vänta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="394"/>
        <location filename="../mainwindow.cpp" line="677"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="394"/>
        <location filename="../mainwindow.cpp" line="679"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ditt nya val kommer att träda i kraft nästa gång förråden uppdateras.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>Listor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Förråd (markerade förråd är aktiva)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="614"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="641"/>
        <location filename="../mainwindow.cpp" line="658"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Could not change the repo.</source>
        <translation>Kunde inte ändra förrådet</translation>
    </message>
    <message>
        <source>About MX Repo Manager</source>
        <translation type="vanished">Om MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program för att välja standard Apt förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licens</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Ändringslogg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Du har valt MX Test Repo. Det är inte rekommendabelt att lämna dom aktiverade eller att uppgradera alla paket från det.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ett säkrare val är att installera paket individuellt med MX Paket Installerare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Välj det APT-förråd och källor du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>MX version not detected or out of range: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="658"/>
        <source>Could not download original APT files.</source>
        <translation>Kunde inte ladda ner original APT filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Could not unzip downloaded file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Enabling AHS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Original APT sources har återställts till ursprunglig status. Source-filer tillagda av användare i /etc/apt/sources.list.d/ har inte ändrats.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Du måste köra detta program som root</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Error</source>
        <translation type="unfinished">Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-repo-manager_23.9.tar.xz: mx-repo-manager-23.9/translations/mx-repo-manager_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Välj det APT förråd du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Välj snabbaste MX förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Välj snabbaste Debian förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Individuella källor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Återställ original APT sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="467"/>
        <location filename="../mainwindow.cpp" line="764"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <location filename="../mainwindow.cpp" line="467"/>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ditt nya val kommer att träda i kraft nästa gång förråden uppdateras.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Lists</source>
        <translation>Listor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Förråd (markerade förråd är aktiva)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <location filename="../mainwindow.cpp" line="673"/>
        <location filename="../mainwindow.cpp" line="683"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <location filename="../mainwindow.cpp" line="715"/>
        <location filename="../mainwindow.cpp" line="723"/>
        <location filename="../mainwindow.cpp" line="740"/>
        <location filename="../mainwindow.cpp" line="746"/>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Could not change the repo.</source>
        <translation>Kunde inte ändra förrådet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Please wait...</source>
        <translation>Var vänlig vänta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program för att välja standard Apt förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Du har valt MX Test Repo. Det är inte rekommendabelt att lämna dom aktiverade eller att uppgradera alla paket från det.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ett säkrare val är att installera paket individuellt med MX Paket Installerare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Välj det APT-förråd och källor du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="715"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>
Vet inte om den här appen fungerar med  antiX eller MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX version ej hittad eller utanför skalan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Could not download original APT files.</source>
        <translation>Kunde inte ladda ner original APT filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Kunde inte packa upp den nedladdade filen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <source>Enabling AHS</source>
        <translation>Möjliggör AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="757"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Använder du AHS (Advanced Hardware Stack) förråd?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Original APT sources har återställts till ursprunglig status. Source-filer tillagda av användare i /etc/apt/sources.list.d/ har inte ändrats.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ett fel uppstod vid skrivande av fil: %1. Var vänlig kontrollera att du har tillräckligt mycket ledigt utrymme på disken.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
</context>
</TS>
